/*      -*- linux-c -*-
 *
 * (C) Copyright IBM Corp. 2004, 2006
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. This
 * file and program are licensed under a BSD style license. See
 * the Copying file included with the OpenHPI distribution for
 * full licensing terms.
 */

#ifndef __EL_H
#define __EL_H

#define LOG_LOGIN_STRING "Login ID:"
#define LOG_POST_STRING "(POST Status:"
#define EVT_RECOVERY "Recovery "
#define LOG_THRESHOLD_VALUE_STRING "Threshold value"
#define LOG_THRESHOLD_STRING "Threshold:"
#define EVT_EN_LOG_FULL "System error log full"
#define ER_STR_POST_LOG_CLEARED "System log cleared."
#define LOG_READ_VALUE_STRING "Read value"
#define LOG_READ_STRING "Reading:"
#define LOG_LOGIN_CHAR "'"
#define LOG_DISCOVERING "Discovering"

#endif
